watch-fs
========

``watch-fs`` is a command line tool to run commands when files change.

Usage
-----

``watch-fs`` will watch any number of directories and files, and run a command
when any of them are changed.

::

	watch-fs [-d DIR] <command>

By default, ``watch-fs`` will watch the current directory.

Installation
------------

::

	pip install watch-fs

Licence
-------

``watch-fs`` is licensed under the MIT Licence.
